import Layout from '@/layout'
import { h, resolveComponent } from 'vue'

const HomeRoutes = {
  path: '/baggageManagement',
  component: Layout,
  name: 'baggageManagement',
  redirect: '/baggageManagement/departure',
  //using el svg icon, the elSvgIcon first when at the same time using elSvgIcon and icon
  meta: { title: '综合可视化', elSvgIcon: 'Fold' },
  children: [
    {
      path: '/baggageManagement/departure',
      name: 'InternalDeparture',
      redirect: '/baggageManagement/departure/station',
      meta: { title: '国内出港', elSvgIcon: 'Fold', icon: 'table' },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/baggageManagement/departure/station',
          name: 'DepartureStation',
          meta: { title: '国内出港航站视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import('@/views/baggageManagement/departure/station/index.vue'),
        },
        {
          path: '/baggageManagement/departure/flight',
          name: 'DepartureFlight',
          meta: { title: '国内出港航班视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import('@/views/baggageManagement/departure/flight/index.vue'),
        },
        {
          path: '/baggageManagement/departure/waybill',
          name: 'DepartureWaybill',
          meta: { title: '国内出港运单视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import('@/views/baggageManagement/departure/waybill/index.vue'),
        },
        {
          path: '/baggageManagement/departure/goods',
          name: 'DepartureGoods',
          meta: { title: '国内出港货物视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import('@/views/baggageManagement/departure/goods/index.vue'),
        },
      ],
    },
    {
      path: '/baggageManagement/internationalDeparture',
      name: 'InternationalDeparture',
      redirect: '/baggageManagement/internationalDeparture/station',
      meta: { title: '国际出港', elSvgIcon: 'Fold', icon: 'table' },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/baggageManagement/internationalDeparture/station',
          name: 'InternationalDepartureStation',
          meta: { title: '国际出港航站视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import(
              '@/views/baggageManagement/internationalDeparture/station/index.vue'
            ),
        },
        {
          path: '/baggageManagement/internationalDeparture/flight',
          name: 'InternationalDepartureFlight',
          meta: { title: '国际出港航班视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import(
              '@/views/baggageManagement/internationalDeparture/flight/index.vue'
            ),
        },
        {
          path: '/baggageManagement/internationalDeparture/waybill',
          name: 'InternationalepartureWaybill',
          meta: { title: '国际出港运单视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import(
              '@/views/baggageManagement/internationalDeparture/waybill/index.vue'
            ),
        },
        {
          path: '/baggageManagement/internationalDeparture/goods',
          name: 'InternationalDepartureGoods',
          meta: { title: '国际出港货物视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import(
              '@/views/baggageManagement/internationalDeparture/goods/index.vue'
            ),
        },
      ],
    },
    {
      path: '/baggageManagement/arrival',
      name: 'Arrival',
      redirect: '/baggageManagement/arrival/station',
      meta: { title: '国内进港', elSvgIcon: 'Fold', icon: 'table' },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/baggageManagement/arrival/station',
          name: 'ArrivalStation',
          meta: { title: '国内进港航站视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import('@/views/baggageManagement/arrival/station/index.vue'),
        },
        {
          path: '/baggageManagement/arrival/flight',
          name: 'ArrivalFlight',
          meta: { title: '国内进港航班视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import('@/views/baggageManagement/arrival/flight/index.vue'),
        },
        {
          path: '/baggageManagement/arrival/waybill',
          name: 'ArrivalWaybill',
          meta: { title: '国内进港运单视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import('@/views/baggageManagement/arrival/waybill/index.vue'),
        },
        {
          path: '/baggageManagement/arrival/goods',
          name: 'ArrivalGoods',
          meta: { title: '国内进港货物视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import('@/views/baggageManagement/arrival/goods/index.vue'),
        },
      ],
    },
    {
      path: '/baggageManagement/internationalArrival',
      name: 'InternationalArrival',
      redirect: '/baggageManagement/internationalArrival/station',
      meta: { title: '国际进港', elSvgIcon: 'Fold', icon: 'table' },
      component: {
        render: () => h(resolveComponent('router-view')),
      },
      children: [
        {
          path: '/baggageManagement/internationalArrival/station',
          name: 'InternationalArrivalStation',
          meta: { title: '国际进港航站视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import(
              '@/views/baggageManagement/internationalArrival/station/index.vue'
            ),
        },
        {
          path: '/baggageManagement/internationalArrival/flight',
          name: 'InternationalArrivalFlight',
          meta: { title: '国际进港航班视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import(
              '@/views/baggageManagement/internationalArrival/flight/index.vue'
            ),
        },
        {
          path: '/baggageManagement/internationalArrival/waybill',
          name: 'InternationalArrivalWaybill',
          meta: { title: '国际进港运单视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import(
              '@/views/baggageManagement/internationalArrival/waybill/index.vue'
            ),
        },
        {
          path: '/baggageManagement/internationalArrival/goods',
          name: 'InternationalArrivalGoods',
          meta: { title: '国际进港货物视图', elSvgIcon: 'Fold', icon: 'table' },
          component: () =>
            import(
              '@/views/baggageManagement/internationalArrival/goods/index.vue'
            ),
        },
      ],
    },
    {
      path: '/baggageManagement/trackMap',
      name: 'TrackMap',
      meta: { title: '轨迹地图', elSvgIcon: 'Fold', icon: 'table' },
      component: () => import('@/views/baggageManagement/trackMap/index.vue'),
    },
  ],
}

export default [HomeRoutes]
